# Table of Contents

- [radar-report](<./radar-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Radar Report](<./Radar-Report.md>)
  - [Overview](<./Radar-Report/Overview.md>)
  - [Configuring Rings and Sectors for Fact Sheet Classification](<./Radar-Report/Configuring-Rings-and-Sectors-for-Fact-Sheet-Classification.md>)
  - [Applying Views](<./Radar-Report/Applying-Views.md>)
  - [Applying Filters](<./Radar-Report/Applying-Filters.md>)
  - [Side Panel for Additional Information](<./Radar-Report/Side-Panel-for-Additional-Information.md>)
  - [Organization-Specific Technology Assessment](<./Radar-Report/Organization-Specific-Technology-Assessment.md>)
  - [Was this page helpful?](<./Radar-Report/Was-this-page-helpful.md>)
